@@ -41,6 +41,9 @@ from turberfield.utils.misc import group_by_type
 
 import pkg_resources
 import docutils
+from docutils.nodes import field_body
+from docutils.nodes import list_item
+
 
 
 class Model(docutils.nodes.GenericNodeVisitor):
@@ -72,8 +75,8 @@ class Model(docutils.nodes.GenericNodeVisitor):
             "turberfield.dialogue.{0}".format(os.path.basename(self.fP))
         )
         self.section_level = 0
-        self.scenes = []
-        self.shots = []
+        self.scenes = [None]
+        self.shots = [Model.Shot(None, None, [])]
         self.speaker = None
         self.memory = None
         self.metadata = []
@@ -82,12 +85,27 @@ class Model(docutils.nodes.GenericNodeVisitor):
             if k.endswith(";") and len(v) == 1
             and v not in "!\"#'()*+,-..:;=@{}~"
         })
+        self.text = []
+        self.html = []
 
     def __iter__(self):
         for shot in self.shots:
             for item in shot.items:
                 yield shot, item
 
+    def close_shot(self):
+        if self.memory:
+            self.shots[-1].items.append(
+                self.memory._replace(text="".join(self.text), html="\n".join(self.html))
+            )
+            self.memory = None
+        elif self.text:
+            self.shots[-1].items.append(
+                Model.Line(self.speaker, "".join(self.text), "\n".join(self.html))
+            )
+            self.text.clear()
+            self.html.clear()
+
     def get_entity(self, ref):
         return next((
             entity
@@ -116,9 +134,16 @@ class Model(docutils.nodes.GenericNodeVisitor):
     def default_departure(self, node):
         pass
 
+    def visit_bullet_list(self, node):
+        self.html.append("<ul>")
+
+    def depart_bullet_list(self, node):
+        self.html.append("</ul>")
+        self.close_shot()
+
     def visit_citation_reference(self, node):
         entity = self.get_entity(node.attributes["refname"])
-        self.speaker = entity.persona
+        self.speaker = entity and entity.persona
 
     def visit_Cue(self, node):
         subref_re = re.compile("\|(\w+)\|")
@@ -160,19 +185,26 @@ class Model(docutils.nodes.GenericNodeVisitor):
         ref, attr = node["arguments"][0].split(".")
         entity = self.get_entity(ref)
         s = re.compile("\|(\w+)\|").sub(self.substitute_property, node["arguments"][1])
-        val = int(s) if s.isdigit() else node.string_import(s)
+        try:
+            val = int(s) if s.isdigit() else node.string_import(s)
+        except ValueError:
+            val = s
         self.shots[-1].items.append(Model.Condition(entity.persona, attr, val, operator.eq))
 
-    def depart_field(self, node):
-        if self.section_level == 0:
-            data = tuple(
-                ("\n".join([" ".join(getattr(p, "text", [p.rawsource])) for p in f.children])
-                 if f.tagname == "field_body" else f.rawsource).strip()
-                for f in node.children
-            )
-            if data not in self.metadata:
-                self.log.debug(data)
-                self.metadata.append(data)
+    def depart_field_name(self, node):
+        self.metadata.append((node.astext(), None))
+
+    def depart_field_body(self, node):
+        name, _ = self.metadata.pop(-1)
+        self.metadata.append((name, " ".join(self.text)))
+        self.text.clear()
+
+    def visit_list_item(self, node):
+        self.html.append("<li>")
+
+    def depart_list_item(self, node):
+        self.html.append("</li>")
+        self.text.append("\n")
 
     def visit_literal(self, node):
         text = node.astext()
@@ -182,24 +214,20 @@ class Model(docutils.nodes.GenericNodeVisitor):
         ))
 
     def visit_paragraph(self, node):
-        self.text = []
-        self.html = []
+        if self.shots and not isinstance(node.parent, (field_body, list_item)):
+            self.text = []
+            self.html = ["<p>"]
 
     def depart_paragraph(self, node):
-        if self.memory:
-            self.shots[-1].items.append(
-                self.memory._replace(text="".join(self.text), html="\n".join(self.html))
-            )
-            self.memory = None
-        elif self.section_level == 0:
-            node.text = self.text
-            node.html = self.html
-        elif (self.text or self.html) and self.section_level == 2:
-            self.shots[-1].items.append(
-                Model.Line(self.speaker, "".join(self.text), "\n".join(self.html))
-            )
-            del self.text
-            del self.html
+        if self.shots and not isinstance(node.parent, (field_body, list_item)):
+            self.html.append("</p>\n")
+            self.close_shot()
+
+    def depart_raw(self, node):
+        if "html" in node.attributes["format"] and self.shots:
+            if self.shots[-1].items:
+                line = self.shots[-1].items[-1]
+                self.shots[-1].items[-1] = line._replace(html=line.html + "\n" + node.astext())
 
     def visit_reference(self, node):
         ref_id = self.document.nameids.get(node.get("refname", None), None)
@@ -225,8 +253,15 @@ class Model(docutils.nodes.GenericNodeVisitor):
         ref, attr = node["arguments"][0].split(".")
         entity = self.get_entity(ref)
         s = re.compile("\|(\w+)\|").sub(self.substitute_property, node["arguments"][1])
-        val = int(s) if s.isdigit() else node.string_import(s)
-        self.shots[-1].items.append(Model.Property(self.speaker, entity.persona, attr, val))
+        try:
+            val = int(s) if s.isdigit() else node.string_import(s)
+        except ValueError:
+            val = s
+
+        try:
+            self.shots[-1].items.append(Model.Property(self.speaker, entity.persona, attr, val))
+        except AttributeError:
+            warnings.warn("Entity {0} has no persona.".format(entity))
 
     def visit_strong(self, node):
         text = node.astext()
@@ -274,6 +309,10 @@ class Model(docutils.nodes.GenericNodeVisitor):
 
     def visit_title(self, node):
         self.log.debug(self.section_level)
+        if self.scenes == [None] and self.shots == [Model.Shot(None, None, [])]:
+            self.scenes.clear()
+            self.shots.clear()
+
         if isinstance(node.parent, docutils.nodes.section):
             if self.section_level == 1:
                 self.scenes.append(node.parent.attributes["names"][0])
@@ -283,6 +322,7 @@ class Model(docutils.nodes.GenericNodeVisitor):
                     self.scenes[-1],
                     []))
 
+
 class SceneScript:
     """Gives access to a Turberfield scene script (.rst) file.
 
@@ -306,7 +346,11 @@ class SceneScript:
         pep_references=1,
         report_level=2, rfc_references=1,
         strict_visitor=False, tab_width=4,
-        warning_stream=sys.stderr
+        warning_stream=sys.stderr,
+        raw_enabled=True,
+        file_insertion_enabled=True,
+        input_encoding="utf-8",
+        input_encoding_error_handler="replace"
     )
 
     docutils.parsers.rst.directives.register_directive(
