@@ -42,6 +42,46 @@ class PropertyDirectiveTests(unittest.TestCase):
         object()
     ]
 
+    def test_dialogue_at_level_0(self):
+        content = textwrap.dedent(
+            """
+            .. entity:: P
+
+            [P]_
+
+                You can call me |P_NICKNAME|.
+
+            .. |P_NICKNAME| property:: P.nickname
+            """)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        script.cast(script.select([self.personae[0]]))
+        model = list(script.run())
+        shot, line = next(iter(model))
+        self.assertIs(None, shot.scene)
+        self.assertIs(None, shot.name)
+        self.assertIn(line.text, (
+            "You can call me Fuzzer.",
+            "You can call me Q.A."))
+
+    def test_dialogue_at_level_1(self):
+        content = textwrap.dedent(
+            """
+            .. entity:: P
+
+            Scene
+            =====
+
+            [P]_
+
+                You can call me |P_NICKNAME|.
+
+            .. |P_NICKNAME| property:: P.nickname
+            """)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        script.cast(script.select([self.personae[0]]))
+        model = list(script.run())
+        self.assertFalse(model)
+
     def test_property_getter(self):
         content = textwrap.dedent("""
             .. entity:: P
@@ -80,7 +120,7 @@ class PropertyDirectiveTests(unittest.TestCase):
         metadata = dict(model.metadata)
         self.assertIn("copyright", metadata)
         self.assertIn("version", metadata)
-        self.assertEqual(2, metadata["version"].count("."))
+        self.assertEqual(2, metadata["version"].count("."), metadata)
 
     def test_nickname_getter(self):
         content = textwrap.dedent(
@@ -101,7 +141,7 @@ class PropertyDirectiveTests(unittest.TestCase):
             """)
         script = SceneScript("inline", doc=SceneScript.read(content))
         script.cast(script.select([self.personae[0]]))
-        model = script.run()
+        model = list(script.run())
         shot, line = next(iter(model))
         self.assertEqual("scene", shot.scene)
         self.assertEqual("shot", shot.name)
@@ -747,6 +787,27 @@ class HTMLEscapingTests(unittest.TestCase):
 
 class RstFeatureTests(unittest.TestCase):
 
+    def test_bullet_lists(self):
+        content = textwrap.dedent("""
+            Scene
+            =====
+
+            Shot
+            ----
+
+            ABC.
+
+            * Always
+            * Be
+            * Closing
+
+        """)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        model = script.run()
+        self.assertEqual(["Always", "Be", "Closing"], model.shots[-1].items[-1].text.splitlines())
+        self.assertEqual(2, model.shots[-1].items[-1].html.count("ul>"))
+        self.assertEqual(6, model.shots[-1].items[-1].html.count("li>"))
+
     def test_markup_body_text(self):
         content = textwrap.dedent("""
             Markup
@@ -818,3 +879,22 @@ class RstFeatureTests(unittest.TestCase):
             with self.subTest(shot_name=shot.name):
                 self.assertFalse(any("  " in line.text for line in shot.items))
                 self.assertTrue(all('<a href="http://www.python.org">' in i.html for i in shot.items), shot)
+
+    def test_raw_html(self):
+        content = textwrap.dedent("""
+            Scene
+            =====
+
+            Shot
+            ----
+
+            I know what it needs...
+
+            .. raw:: html
+
+                <marquee>Puppies die when you do bad design</marquee>
+        """)
+        script = SceneScript("inline", doc=SceneScript.read(content))
+        model = script.run()
+        self.assertEqual(2, model.shots[-1].items[-1].html.count("marquee"))
+        self.assertEqual(0, model.shots[-1].items[-1].text.count("marquee"))
